@@ -1,11 +1,12 @@
-package Email::Folder::IMAP;
 use strict;
+use warnings;
+package Email::Folder::IMAP;
+# ABSTRACT: Email::Folder Access to IMAP Folders
 
-use vars qw[$VERSION];
-$VERSION = '1.102';
+our $VERSION = '1.102';
 
-use base qw[Email::Folder::Reader];
-use Net::IMAP::Simple;
+use parent qw[Email::Folder::Reader];
+use Net::IMAP::Simple 0.95; # :port support
 use URI;
 
 sub _imap_class {
@@ -53,10 +54,16 @@ sub next_message {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Email::Folder::IMAP - Email::Folder Access to IMAP Folders
 
+=head1 VERSION
+
+version 1.103
+
 =head1 SYNOPSIS
 
   use Email::Folder;
@@ -105,20 +112,15 @@ L<Email::FolderType::Net>,
 L<URI::imap>,
 L<Net::IMAP::Simple>.
 
-=head1 PERL EMAIL PROJECT
-
-This module is maintained by the Perl Email Project.
-
-L<http://emailproject.perl.org/wiki/Email::Folder::IMAP>
-
 =head1 AUTHOR
 
-Casey West, <F<casey@geeknest.com>>.
+Casey West <casey@geeknest.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-  Copyright (c) 2004 Casey West.  All rights reserved.
-  This module is free software; you can redistribute it and/or modify it
-  under the same terms as Perl itself.
+This software is copyright (c) 2004 by Casey West <casey@geeknest.com>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
